__all__ = ['DaqChannel']
from ..lasp_common import Qty, SIQtys
from dataclasses import dataclass, field
from dataclasses_json import dataclass_json
from typing import List
import json

@dataclass_json
@dataclass
class DaqChannel:
    channel_enabled: bool
    channel_name: str = 'Unnamed channel'
    sensitivity: float = 1.0
    range_index: int = 0
    ACCoupling_enabled: bool = False
    IEPE_enabled: bool = False
    channel_metadata: str = ''

    def __post_init__(self):
        self.qty = SIQtys.default

    @property
    def qty(self):
        return self._qty

    @qty.setter
    def qty(self, newqty):
        self._qty = newqty
        self._store('qty', newqty)

    def _store(self, name, val):
        if len(self.channel_metadata) > 0:
            meta = json.loads(self.channel_metadata)
        else:
            meta = {}

        meta[name] = val.to_json()
        self.channel_metadata = json.dumps(meta)

